@@ -7,39 +7,39 @@ os.system("")  # print颜色开启(玄学)
 isPrint = True
 
 # 定义颜色，方便简打
-__color_black = "black"
-__color_red = "red"
-__color_green = "green"
-__color_yellow = "yellow"
-__color_blue = "blue"
-__color_purplered = "purple-red"
-__color_cyanine = "cyanine"
-__color_white = "white"
-__color_default = "default"
+color_black = "black"
+color_red = "red"
+color_green = "green"
+color_yellow = "yellow"
+color_blue = "blue"
+color_purplered = "purple-red"
+color_cyanine = "cyanine"
+color_white = "white"
+color_default = "default"
 
-__background_black = "black"
-__background_red = "red"
-__background_green = "green"
-__background_yellow = "yellow"
-__background_blue = "blue"
-__background_purplered = "purple-red"
-__background_cyanine = "cyanine"
-__background_white = "white"
-__background_default = "default"
+background_black = "black"
+background_red = "red"
+background_green = "green"
+background_yellow = "yellow"
+background_blue = "blue"
+background_purplered = "purple-red"
+background_cyanine = "cyanine"
+background_white = "white"
+background_default = "default"
 
-__effect_default = "default"
-__effect_highlight = "highlight"
-__effect_underline = "underline"
-__effect_flash = "flash"
-__effect_backwhite = "backwhite"
-__effect_unshow = "unshow"
+effect_default = "default"
+effect_highlight = "highlight"
+effect_underline = "underline"
+effect_flash = "flash"
+effect_backwhite = "backwhite"
+effect_unshow = "unshow"
 
-__Type_error = "error"
-__Type_warning = "warning"
-__Type_success = "success"
-__Type_data = "data"
-__Type_system = "system"
-__Type_normal = "normal"
+Type_error = "error"
+Type_warning = "warning"
+Type_success = "success"
+Type_data = "data"
+Type_system = "system"
+Type_normal = "normal"
 
 
 def set_isPrint(is_print=True):
